@@ -78,7 +78,7 @@ get_nested_model_coefficients <- function(model,
       # If parameters::model_parameters wasn't implemented for the model type
       # let's grab the coefficients manually if possible
 
-      if (grepl("does currently not work for objects of class",
+      if (grepl("not supported",
                 as.character(e),
                 ignore.case = TRUE)) {
 
